.. KM3Pipe documentation master file, created by
   sphinx-quickstart on Sat Oct  4 19:16:43 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to KM3Pipe's documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 3

   data_structures
   help_modules
   help_pumps
   examples
   pipeinspector
   api/modules

.. include:: ../README.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

